@@ -11,13 +11,13 @@
 
 #include <kpopupmenu.h>
 #include <qtimer.h>
+#include <qcursor.h>
 
 #include <klocale.h>
-#include <ksimpleconfig.h>
 #include <kmessagebox.h>
+#include <kstartupinfo.h>
 #include <kwin.h>
 #include <kwinmodule.h>
-#include <kapp.h>
 
 #include "amor.h"
 #include "amor.moc"
@@ -26,7 +26,6 @@
 #include "amorwidget.h"
 #include "amordialog.h"
 #include "version.h"
-#include <kdebug.h>
 #include <X11/Xlib.h>
 
 #define SLEEP_TIMEOUT   180     // Animation sleeps after SLEEP_TIMEOUT seconds
@@ -100,6 +99,8 @@ Amor::Amor() : QObject(), DCOPObject( "AmorIface" )
             selectAnimation(Focus);
             mTimer->start(0, true);
         }
+
+        KStartupInfo::appStarted();
     }
     else
     {
@@ -279,9 +280,12 @@ void Amor::selectAnimation(State state)
 		{
 		    if (mCurrAnim->frame())
 		    {
-			mPosition = (kapp->random() %
-			    (mTargetRect.width() - mCurrAnim->frame()->width())) +
-			     mCurrAnim->hotspot().x();
+		        if (mTargetRect.width() == mCurrAnim->frame()->width())
+			    mPosition = mCurrAnim->hotspot().x();
+			else
+			    mPosition = ( kapp->random() %
+					  (mTargetRect.width() - mCurrAnim->frame()->width()) )
+					 + mCurrAnim->hotspot().x();
 		    }
 		    else
 		    {
