@@ -6,14 +6,11 @@
 //
 
 #include <stdlib.h>
-#include <kapp.h>
+#include <kapplication.h>
 #include "amortips.h"
-#include <kglobal.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <klocale.h>
-#include <kdebug.h>
 #include <qfile.h>
-#include <qtextstream.h>
 
 //---------------------------------------------------------------------------
 //
