@@ -19,13 +19,10 @@
 #include <math.h>
 
 #include <qpainter.h>
-#include <qxembed.h>
-#include <qpopupmenu.h>
 
 #include <klocale.h>
 #include <kglobal.h>
-#include <kapp.h>
-#include <kdebug.h>
+#include <kapplication.h>
 
 #include "eyes.h"
 #include "eyes.moc"
