@@ -1,6 +1,6 @@
 /*
  *   kmoon - a moon phase indicator
- *   $Id: kmoon.cpp,v 1.33 2001/05/11 12:21:09 bhughes Exp $
+ *   $Id: kmoon.cpp,v 1.35 2001/10/10 21:12:17 mueller Exp $
  *   Copyright (C) 1998,2000  Stephan Kulow
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -23,25 +23,20 @@
 #include <assert.h>
 #include <unistd.h>
 
-#include <qwidget.h>
-#include <qwmatrix.h>
 #include <qbitmap.h>
 #include <qtooltip.h>
 #include <qpainter.h>
-#include <qimage.h>
 #include <qpopupmenu.h>
 
 #include <dcopclient.h>
 #include <kdebug.h>
-#include <kapp.h>
+#include <kapplication.h>
 #include <kwin.h>
 #include <kmessagebox.h>
 #include <kaboutdata.h>
 #include <klocale.h>
-#include <kglobal.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <kcmdlineargs.h>
-#include <kstdaction.h>
 #include <kiconloader.h>
 #include <kconfig.h>
 
@@ -49,7 +44,6 @@
 #include "kmoondlg.h"
 #include "kmoon.h"
 
-#include <qapplication.h>
 #include <X11/Xlib.h>
 
 extern Time qt_x_time;
