@@ -21,13 +21,12 @@
 #include "kmoondlg.h"
 #include <qslider.h>
 #include <qlayout.h>
-#include <qlabel.h>
 #include <klocale.h>
 #include "kmoon.h"
 #include <qwhatsthis.h>
 #include <qvbox.h>
-#include <kapp.h>
-#include <qpixmap.h>
+#include <kapplication.h>
+#include <qpushbutton.h>
 
 KMoonDlg::KMoonDlg(int _angle, bool n, QWidget *parent, const char *name)
     : KDialogBase(parent, name, true, i18n("Change View"),
@@ -61,8 +60,12 @@ KMoonDlg::KMoonDlg(int _angle, bool n, QWidget *parent, const char *name)
 	QWhatsThis::add(slider, text);
 	connect(slider, SIGNAL(valueChanged(int)), SLOT(valueChanged(int)));
 
-        QPushButton *hemitoggle = new QPushButton(vbox);
-        hemitoggle->setText(i18n("Toggle Hemisphere"));
+        hemitoggle = new QPushButton(vbox);
+	if (north)
+	    hemitoggle->setText(i18n("Switch to Southern Hemisphere"));
+	else
+	    hemitoggle->setText(i18n("Switch to Northern Hemisphere"));
+
         connect(hemitoggle, SIGNAL(clicked()), SLOT(toggleHemi()));
 
         topLayout->addWidget(vbox);
@@ -89,6 +92,10 @@ void KMoonDlg::help() {
 void KMoonDlg::toggleHemi() {
     moon->setNorthHemi(!moon->northHemi());
     north = moon->northHemi();
+    if (north)
+	hemitoggle->setText(i18n("Switch to Southern Hemisphere"));
+    else
+	hemitoggle->setText(i18n("Switch to Northern Hemisphere"));
 }
 
 #include "kmoondlg.moc"
