@@ -7,15 +7,11 @@
 
 #include <stdlib.h>
 #include <time.h>
-#include <qcolor.h>
 #include <qlabel.h>
-#include <qgroupbox.h>
 #include <qmessagebox.h>
 #include <qlayout.h>
 #include <qslider.h>
-#include <kapp.h>
-#include <kglobal.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <klocale.h>
 #include <kdebug.h>
 
