@@ -44,10 +44,10 @@ void reportView::render(){
     "<h3> " + i18n( "Weather Report as of Current_Date " ) + "</h3><hr />"
     "<table><tr><th colspan=\"2\">" + i18n( "Current Conditions:" ) + "</th></tr>"
     "<tr><td><img width=\"48\" height=\"48\" src=\"Current_Icon\" /></td><td>Current_Weather</td></tr>"
-    "<tr><th>" + i18n( "Temperature:" ) + "</th><td>Current_Temp</td></tr>"
-    "<tr><th>" + i18n( "Air Pressure:" ) + "</th><td>Current_Pressure</td></tr>"
-    "<tr><th>" + i18n( "WindSpeed:" ) + "</th><td>Current_Wind</td></tr></table>"
-    "<hr /></body></html>";
+    "<tr><th style=\"text-align: right\">" + i18n( "Temperature:" ) + "</th><td>Current_Temp</td></tr>"
+    "<tr><th style=\"text-align: right\">" + i18n( "Air Pressure:" ) + "</th><td>Current_Pressure</td></tr>"
+    "<tr><th style=\"text-align: right\">" + i18n( "WindSpeed:" ) + "</th><td>Current_Wind</td></tr></table>"
+    "</body></html>";
 
     QString weatherText = "<ul>\n";
 
