@@ -28,7 +28,7 @@ weatherlib::weatherlib(QString location)
     reportLocation = location;
     CoverRegExp    = QRegExp("^(FEW|SCT|BKN|OVC|SKC|CLR|CAVOK)([0-9]{3})?");
     CurrentRegExp  = QRegExp("^(\\+|-|VC)?([A-Z]{2,4})$");
-    WindRegExp     = QRegExp("^([0-9]{3}|VRB)([0-9]{2,3})(?:G([0-9]{2,3}))?KT$");
+    WindRegExp     = QRegExp("^([0-9]{3}|VRB)([0-9]{2,3})(?:G([0-9]{2,3}))?(KT|KMH|MPS)$");
     // VisRegExp does not work with fractions...yet
     VisRegExp      = QRegExp("^([0-9]{1,2})SM$");
     TempRegExp     = QRegExp("^(M)?([0-9]{2})/(?:(M)?([0-9]{2}))?$");
@@ -313,50 +313,67 @@ void weatherlib::parseWindSpeed( QString s)
 {
     if (WindRegExp.search(s) > -1)
     {
-
         int iDirection = WindRegExp.cap(1).toInt();
         int iWindSpeed = WindRegExp.cap(2).toInt();
         int iGustSpeed = WindRegExp.cap(3).toInt();
+        QString sWindUnit = WindRegExp.cap(4);
 
         kdDebug() << "Wind: " << WindRegExp.capturedTexts().join("-") << endl;
 
         if (MetricMode)
         {
-            iWindSpeed = (int) (iWindSpeed * 3.6/1.94);
+            if (sWindUnit == "KT")
+            {
+                iWindSpeed = (int) (iWindSpeed * 3.6/1.94);
+                iGustSpeed = (int) (iGustSpeed * 3.6/1.94);
+            }
+            else if (sWindUnit == "MPS")
+            {
+                iWindSpeed = (int) (iWindSpeed * 3.6);
+                iGustSpeed = (int) (iGustSpeed * 3.6);
+            }
             qsWindSpeed.setNum(iWindSpeed);
             qsWindSpeed += i18n(" KPH");
         }
         else
         {
-            iWindSpeed =(int) (iWindSpeed * 2.24/1.94);
+            if (sWindUnit == "KT")
+            {
+                iWindSpeed = (int) (iWindSpeed * 2.24/1.94);
+                iGustSpeed = (int) (iGustSpeed * 2.24/1.94);
+            }
+            else if (sWindUnit == "KMH")
+            {
+                iWindSpeed = (int) (iWindSpeed / 1.61);
+                iGustSpeed = (int) (iGustSpeed / 1.61);
+            }
+            else if (sWindUnit == "MPS")
+            {
+                iWindSpeed = (int) (iWindSpeed * 2.24);
+                iGustSpeed = (int) (iGustSpeed * 2.24);
+            }
             qsWindSpeed.setNum(iWindSpeed);
             qsWindSpeed += i18n(" MPH");
         }
 
-        // Take care of the wind directions...
-        //	  N   	  E	- 338-22  W - 156-203
-        // NW | NE    NE- 23-68   SW- 204-248
-        //W--`+'--E   N - 69-112  S - 249-294
-        // SW'|`SE    NW- 113-157 SE- 295-337
-        //    S
-        if (WindRegExp.cap(1) != "VRB")
+        if ((WindRegExp.cap(1) != "VRB") && (iWindSpeed > 0))
         {
-            if ((iDirection >=0 && iDirection < 23) || ( iDirection >= 239 && iDirection <= 360))
-                qsWindDirection = i18n("E");
-            else if ((iDirection >=23 && iDirection < 69))
-                qsWindDirection = i18n("NE");
-            else if ((iDirection >=69 && iDirection < 113))
+            if ((iDirection >=0 && iDirection <= 22) || ( iDirection >= 338 && iDirection <= 360))
                 qsWindDirection = i18n("N");
-            else if ((iDirection >=113 && iDirection < 157))
-                qsWindDirection = i18n("NW");
-            else if ((iDirection >=157 && iDirection < 203))
-                qsWindDirection = i18n("W");
-            else if ((iDirection >=203 && iDirection < 248))
-                qsWindDirection = i18n("SW");
-            else if ((iDirection >=248 && iDirection < 294))
-                qsWindDirection = i18n("S");
-            else if ((iDirection >=294 && iDirection < 238))
+            else if (iDirection >= 23 && iDirection <= 67)
+                qsWindDirection = i18n("NE");
+            else if (iDirection >= 68 && iDirection <= 112)
+                qsWindDirection = i18n("E");
+            else if (iDirection >= 113 && iDirection <= 157)
                 qsWindDirection = i18n("SE");
+            else if (iDirection >= 158 && iDirection <= 202)
+                qsWindDirection = i18n("S");
+            else if (iDirection >= 203 && iDirection <= 247)
+                qsWindDirection = i18n("SW");
+            else if (iDirection >= 248 && iDirection <= 292)
+                qsWindDirection = i18n("W");
+            else if (iDirection >= 293 && iDirection <= 337)
+                qsWindDirection = i18n("NW");
         }
     }
 }
