@@ -1,7 +1,7 @@
 #include <qlayout.h>
 
 
-#include <kapp.h>
+#include <kapplication.h>
 #include <kglobal.h>
 #include <klocale.h>
 #include <kiconloader.h>
@@ -28,7 +28,7 @@ KWWApplet::KWWApplet(const QString& configFile, Type type, int actions,
   : KPanelApplet(configFile, type, actions, parent, name)
 {
   // make use of the icons installed for ksaferppp
-  KGlobal::iconLoader()->addAppDir("kworldclock");
+  KGlobal::iconLoader()->addAppDir("kworldwatch");
 
   QVBoxLayout *vbox = new QVBoxLayout(this, 0,0);
   
