@@ -4,7 +4,7 @@
 
 #include <qstring.h>
 #include <qcolor.h>
-#include <qlist.h>
+#include <qptrlist.h>
 #include <qpoint.h>
 #include <qpainter.h>
 #include <qpixmap.h>
@@ -61,7 +61,7 @@ private:
  
   QPoint getPosition(double la, double lo, int w, int h, int offset); 
 
-  QList<Flag> _flags;
+  QPtrList<Flag> _flags;
 
   QPixmap _flagPixmap;
   QBitmap _flagMask;
