@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: flow.h,v 1.1 2001/02/20 15:56:22 hoelzer Exp $
+** $Id: flow.h,v 1.2 2001/09/29 04:02:04 bruggie Exp $
 **
 ** Definition of simple flow layout for custom layout example
 **
@@ -16,7 +16,7 @@
 #define FLOW_H
 
 #include <qlayout.h>
-#include <qlist.h>
+#include <qptrlist.h>
 
 class SimpleFlow : public QLayout
 {
@@ -47,7 +47,7 @@ protected:
 
 private:
     int doLayout( const QRect&, bool testonly = FALSE );
-    QList<QLayoutItem> list;
+    QPtrList<QLayoutItem> list;
     int cached_width;
     int cached_hfw;
 
