@@ -10,7 +10,7 @@
 #include <qimage.h>
 
 
-#include <kapp.h>
+#include <kapplication.h>
 #include <kconfig.h>
 #include <kaboutdata.h>
 #include <kcmdlineargs.h>
