@@ -4,7 +4,7 @@
 
 #include <qpixmap.h>
 #include <qbitmap.h>
-#include <qlist.h>
+#include <qptrlist.h>
 
 
 class MapTheme
@@ -33,7 +33,7 @@ class MapLoader
 {
 public:
 
-  static QList<MapTheme> themes();
+  static QPtrList<MapTheme> themes();
 
   void load(unsigned int width=400, QString theme = "earth", unsigned int height=0);
 
